@@ -15,7 +15,7 @@ module RBS
     end
 
     module NoTypeName
-      def map_type_name
+      def map_type_name(&)
         self
       end
     end
@@ -107,13 +107,15 @@ module RBS
       class Bool < Base; end
       class Void < Base; end
       class Any < Base
-        def to_s(level=0)
-          @string || "untyped"
+        def initialize(location:, todo: false)
+          super(location: location)
+          if todo
+            @string = "__todo__"
+          end
         end
 
-        def todo!
-          @string = '__todo__'
-          self
+        def to_s(level=0)
+          @string || "untyped"
         end
       end
       class Nil < Base; end
@@ -229,7 +231,7 @@ module RBS
 
       include EmptyEachType
 
-      def map_type_name
+      def map_type_name(&)
         ClassSingleton.new(
           name: yield(name, location, self),
           location: location
@@ -323,6 +325,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         self.class.new(name: name,
                        args: args.map {|ty| ty.sub(s) },
                        location: location)
@@ -365,6 +369,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         self.class.new(name: name,
                        args: args.map {|ty| ty.sub(s) },
                        location: location)
@@ -407,6 +413,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         Alias.new(name: name, args: args.map {|ty| ty.sub(s) }, location: location)
       end
 
@@ -463,6 +471,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         self.class.new(types: types.map {|ty| ty.sub(s) },
                        location: location)
       end
@@ -521,15 +531,22 @@ module RBS
       def initialize(all_fields: nil, fields: nil, location:)
         case
         when fields && all_fields.nil?
-          @all_fields = fields.map { |k, v| [k, [v, true]] }.to_h
+          @all_fields = fields.transform_values { |v| [v, true] }
           @fields = fields
           @optional_fields = {}
         when all_fields && fields.nil?
           @all_fields = all_fields
-          @fields = all_fields.filter_map { |k, (v, required)| [k, v] if required }.to_h
-          @optional_fields = all_fields.filter_map { |k, (v, required)| [k, v] unless required }.to_h
+          @fields = {}
+          @optional_fields = {}
+          all_fields.each do |(k, (v, required))|
+            if required
+              @fields[k] = v
+            else
+              @optional_fields[k] = v
+            end
+          end
         else
-          raise ArgumentError, "only one of `:fields` or `:all_fields` is requireds"
+          raise ArgumentError, "only one of `:fields` or `:all_fields` is required"
         end
 
         @location = location
@@ -561,6 +578,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         self.class.new(
           all_fields: all_fields.transform_values {|ty, required| [ty.sub(s), required] },
           location: location
@@ -651,6 +670,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         self.class.new(type: type.sub(s), location: location)
       end
 
@@ -739,15 +760,26 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         self.class.new(types: types.map {|ty| ty.sub(s) },
                        location: location)
       end
 
       def to_s(level = 0)
+        strs = types.map do |ty|
+          case ty
+          when Intersection
+            ty.to_s([1, level].max)
+          else
+            ty.to_s
+          end
+        end
+
         if level > 0
-          "(#{types.join(" | ")})"
+          "(#{strs.join(" | ")})"
         else
-          types.join(" | ")
+          strs.join(" | ")
         end
       end
 
@@ -819,6 +851,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         self.class.new(types: types.map {|ty| ty.sub(s) },
                        location: location)
       end
@@ -1071,6 +1105,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         map_type {|ty| ty.sub(s) }
       end
 
@@ -1221,6 +1257,12 @@ module RBS
         end
       end
 
+      def map_type_name(&block)
+        UntypedFunction.new(
+          return_type: return_type.map_type_name(&block)
+        )
+      end
+
       def each_type(&block)
         if block
           yield return_type
@@ -1244,6 +1286,8 @@ module RBS
       end
 
       def sub(subst)
+        return self if subst.empty?
+
         map_type { _1.sub(subst) }
       end
 
@@ -1318,6 +1362,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         self.class.new(
           type: type.sub(s),
           required: required,
@@ -1387,6 +1433,8 @@ module RBS
       end
 
       def sub(s)
+        return self if s.empty?
+
         self.class.new(
           type: type.sub(s),
           block: block&.sub(s),
@@ -1414,6 +1462,7 @@ module RBS
       def each_type(&block)
         if block
           type.each_type(&block)
+          yield self_type if self_type
           self.block&.type&.each_type(&block)
           if self_type = self.block&.self_type
             yield self_type
@@ -1454,7 +1503,7 @@ module RBS
       end
 
       def with_nonreturn_void?
-        if type.with_nonreturn_void?
+        if type.with_nonreturn_void? || self_type&.with_nonreturn_void?
           true
         else
           if block = block()
