@@ -18,7 +18,7 @@ class RBS::CliTest < Test::Unit::TestCase
   # Run `rbs collection` with fresh bundler environment
   #
   # You need this method to test `rbs collection` features.
-  # `rbs collection` loads gems from Bundler context, so re-using the currenr Bundler context (used to develop rbs gem) causes issues.
+  # `rbs collection` loads gems from Bundler context, so re-using the current Bundler context (used to develop rbs gem) causes issues.
   #
   # - If `bundler: true` is given, it runs `rbs collection` command with `bundle exec`
   # - If `bundler: false` is given, it runs `rbs collection` command without `bundle exec`
@@ -1127,7 +1127,7 @@ Processing `lib`...
           assert_equal <<~EOM, cli.stdout.string
           EOM
 
-          assert_match Regexp.new(Regexp.escape "Geneating prototypes with `--todo` option is experimental"), cli.stderr.string
+          assert_match Regexp.new(Regexp.escape "Generating prototypes with `--todo` option is experimental"), cli.stderr.string
         end
       end
     end
@@ -1174,7 +1174,7 @@ Processing `lib`...
           path: #{dir.join('gem_rbs_collection')}
         YAML
 
-        bundle_install('ast', 'abbrev', 'bigdecimal')
+        bundle_install('ast', 'abbrev', 'bigdecimal', 'logger')
         _stdout, _stderr = run_rbs_collection("install", bundler: true)
 
         rbs_collection_lock = dir.join('rbs_collection.lock.yaml')
@@ -1240,7 +1240,7 @@ Processing `lib`...
           path: #{dir.join('gem_rbs_collection')}
         YAML
 
-        bundle_install('ast', 'abbrev', 'bigdecimal')
+        bundle_install('ast', 'abbrev', 'bigdecimal', 'logger')
         run_rbs_collection("update", bundler: true)
 
         assert dir.join('rbs_collection.lock.yaml').exist?
@@ -1280,7 +1280,7 @@ Processing `lib`...
         RUBY
         (dir/"sig").mkdir
 
-        bundle_install(:gemspec, "abbrev", "bigdecimal")
+        bundle_install(:gemspec, "abbrev", "bigdecimal", "logger")
         stdout, _ = run_rbs_collection("install", bundler: true)
 
         assert_match(/Installing ast:(\d(\.\d)*)/, stdout)
@@ -1310,7 +1310,7 @@ Processing `lib`...
           - name: mutex_m
         YAML
 
-        bundle_install(["mutex_m", ">= 0.3.0"])
+        bundle_install("logger", ["mutex_m", ">= 0.3.0"])
         _stdout, stderr = run_rbs_collection("install", bundler: true)
 
         refute_match(/`mutex_m` as a stdlib in rbs-gem is deprecated./, stderr)
@@ -1343,7 +1343,7 @@ Processing `lib`...
           - name: mutex_m
         YAML
 
-        bundle_install(["mutex_m", "0.2.0"])
+        bundle_install("logger", ["mutex_m", "0.2.0"])
         _stdout, stderr = run_rbs_collection("install", bundler: true)
 
         assert_include stderr, '`mutex_m` as a stdlib in rbs-gem is deprecated.'
@@ -1379,7 +1379,7 @@ Processing `lib`...
               type: stdlib
         YAML
 
-        bundle_install
+        bundle_install("logger")
         _stdout, stderr = run_rbs_collection("install", bundler: true)
 
         assert_include stderr, '`mutex_m` as a stdlib in rbs-gem is deprecated.'
@@ -1410,7 +1410,7 @@ Processing `lib`...
           path: #{dir.join('gem_rbs_collection')}
         YAML
 
-        bundle_install(["mutex_m", ">= 0.3.0"])
+        bundle_install("logger", ["mutex_m", ">= 0.3.0"])
         _stdout, stderr = run_rbs_collection("install", bundler: true)
 
         refute_match(/`mutex_m` as a stdlib in rbs-gem is deprecated./, stderr)
@@ -1440,7 +1440,7 @@ Processing `lib`...
           path: #{dir.join('gem_rbs_collection')}
         YAML
 
-        bundle_install(["mutex_m", "0.2.0"])
+        bundle_install("logger", ["mutex_m", "0.2.0"])
         _stdout, stderr = run_rbs_collection("install", bundler: true)
 
         assert_include stderr, '`mutex_m` as a stdlib in rbs-gem is deprecated.'
@@ -1475,7 +1475,7 @@ Processing `lib`...
           - name: mutex_m
         YAML
 
-        bundle_install("true_string")  # true_string is a soutaro's gem that doesn't have sig directory
+        bundle_install("logger", "true_string")  # true_string is a soutaro's gem that doesn't have sig directory
 
         _stdout, stderr = run_rbs_collection("install", bundler: true)
 
@@ -1519,7 +1519,7 @@ Processing `lib`...
           - name: mutex_m
         YAML
 
-        bundle_install(["hola", { path: "gem" }])
+        bundle_install("logger", ["hola", { path: "gem" }])
 
         (dir + RBS::Collection::Config::PATH).write(<<~YAML)
           sources:
