@@ -225,7 +225,7 @@ class RBS::ParserTest < Test::Unit::TestCase
         module Foo
           type foo = bar
 
-          BAZ: Intger
+          BAZ: Integer
         end
       RBS
 
@@ -733,7 +733,7 @@ class RBS::ParserTest < Test::Unit::TestCase
     end
   end
 
-  def test_neline_inconsitency
+  def test_newline_inconsistency
     code = "module Test\r\nend"
 
     RBS::Parser.parse_signature(code)
@@ -820,12 +820,6 @@ class RBS::ParserTest < Test::Unit::TestCase
     end
   end
 
-  def test_proc__untyped_function_parse_error
-    assert_raises(RBS::ParsingError) do
-      RBS::Parser.parse_type("^(?) { (?) -> void } -> Integer")
-    end
-  end
-
   def test__lex
     content = <<~RBS
       # LineComment
