@@ -2171,4 +2171,112 @@ end
       RBS
     end
   end
+
+  def test_resolved_directive
+    Parser.parse_signature(<<~RBS).tap do |_, dirs, _|
+        # resolve-type-names: false
+
+        module Baz
+        end
+      RBS
+
+      assert_equal 1, dirs.size
+      dirs[0].tap do
+        assert_instance_of RBS::AST::Directives::ResolveTypeNames, _1
+        assert_false _1.value
+        assert_equal "resolve-type-names: false", _1.location.source
+        assert_equal "resolve-type-names", _1.location[:keyword].source
+        assert_equal ":", _1.location[:colon].source
+        assert_equal "false", _1.location[:value].source
+      end
+    end
+
+    Parser.parse_signature(<<~RBS).tap do |_, dirs, _|
+        #resolve-type-names : true
+
+        module Baz
+        end
+      RBS
+
+      assert_equal 1, dirs.size
+      dirs[0].tap do
+        assert_instance_of RBS::AST::Directives::ResolveTypeNames, _1
+        assert_true _1.value
+        assert_equal "resolve-type-names : true", _1.location.source
+        assert_equal "resolve-type-names", _1.location[:keyword].source
+        assert_equal ":", _1.location[:colon].source
+        assert_equal "true", _1.location[:value].source
+      end
+    end
+
+    Parser.parse_signature(<<~RBS).tap do |_, dirs, _|
+        # This is a comment
+        # resolve-type-names: false
+
+        module Baz
+        end
+      RBS
+
+      assert_empty dirs
+    end
+  end
+
+  def test_class_module_alias__annotation
+    Parser.parse_signature(<<~RBS).tap do |_, _, decls|
+        %a{module}
+        module Foo = Kernel
+
+        %a{class} class Bar = Object
+      RBS
+
+      assert_equal 2, decls.size
+      decls[0].tap do |decl|
+        assert_instance_of RBS::AST::Declarations::ModuleAlias, decl
+        assert_equal ["module"], decl.annotations.map(&:string)
+      end
+      decls[1].tap do |decl|
+        assert_instance_of RBS::AST::Declarations::ClassAlias, decl
+        assert_equal ["class"], decl.annotations.map(&:string)
+      end
+    end
+  end
+
+  def test_global__annotation
+    Parser.parse_signature(<<~RBS).tap do |_, _, decls|
+        %a{annotation}
+        $FOO: String
+      RBS
+
+      assert_equal 1, decls.size
+      decls[0].tap do |decl|
+        assert_instance_of RBS::AST::Declarations::Global, decl
+        assert_equal ["annotation"], decl.annotations.map(&:string)
+      end
+    end
+  end
+
+  def test_constant__annotation
+    Parser.parse_signature(<<~RBS).tap do |_, _, decls|
+        %a{annotation}
+        FOO: String
+      RBS
+
+      assert_equal 1, decls.size
+      decls[0].tap do |decl|
+        assert_instance_of RBS::AST::Declarations::Constant, decl
+        assert_equal ["annotation"], decl.annotations.map(&:string)
+      end
+    end
+  end
+
+  def test__method_type__untyped_function_and_block
+    assert_raises(RBS::ParsingError) do
+      Parser.parse_signature(<<~RBS).tap do |_, _, decls|
+          class Foo
+            def foo: (?) { () -> void } -> void
+          end
+        RBS
+      end
+    end
+  end
 end
