@@ -27,6 +27,10 @@ class ARGFTest < Test::Unit::TestCase
                       ARGF.class.new(__FILE__), :gets, "\n"
     assert_send_type  "(::String sep, ::Integer limit) -> ::String",
                       ARGF.class.new(__FILE__), :gets, "\n", 1
+    assert_send_type  "(chomp: boolish) -> ::String",
+                      ARGF.class.new(__FILE__), :gets, chomp: true
+    assert_send_type  "(::String sep, ::Integer limit, chomp: boolish) -> ::String",
+                      ARGF.class.new(__FILE__), :gets, "\n", 1, chomp: true
     assert_send_type  "() -> nil",
                       ARGF.class.new(Tempfile.new), :gets
   end
@@ -60,6 +64,10 @@ class ARGFTest < Test::Unit::TestCase
                       ARGF.class.new(__FILE__), :readline, "\n"
     assert_send_type  "(::String sep, ::Integer limit) -> ::String",
                       ARGF.class.new(__FILE__), :readline, "\n", 1
+    assert_send_type  "(chomp: boolish) -> ::String",
+                      ARGF.class.new(__FILE__), :readline, chomp: true
+    assert_send_type  "(::String sep, ::Integer limit, chomp: boolish) -> ::String",
+                      ARGF.class.new(__FILE__), :readline, "\n", 1, chomp: true
   end
 
   def test_readlines
@@ -69,6 +77,10 @@ class ARGFTest < Test::Unit::TestCase
                       ARGF.class.new(__FILE__), :readlines, "\n"
     assert_send_type  "(::String sep, ::Integer limit) -> ::Array[::String]",
                       ARGF.class.new(__FILE__), :readlines, "\n", 1
+    assert_send_type  "(chomp: boolish) -> ::Array[::String]",
+                      ARGF.class.new(__FILE__), :readlines, chomp: true
+    assert_send_type  "(::String sep, ::Integer limit, chomp: boolish) -> ::Array[::String]",
+                      ARGF.class.new(__FILE__), :readlines, "\n", 1, chomp: true
   end
 
   def test_inspect
