@@ -3,6 +3,13 @@ require_relative "test_helper"
 class EnumerableTest < StdlibTest
   target Enumerable
 
+  def test_enum_for
+    enumerable.enum_for
+    enumerable.enum_for { 0 }
+    enumerable.enum_for(:each)
+    enumerable.enum_for(:each) { 0 }
+  end
+
   def test_find_all
     enumerable.find_all
     enumerable.find_all { |x| x.even? }
@@ -127,7 +134,7 @@ class EnumerableTest < StdlibTest
 end
 
 class EnumerableTest2 < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
 
   class TestEnumerable
     include Enumerable
@@ -194,6 +201,13 @@ class EnumerableTest2 < Test::Unit::TestCase
     ) do end
   end
 
+  def test_enum_for
+    assert_send_type(
+      "() ?{ () -> Integer } -> Enumerator[String, EnumerableTest2::TestEnumerable]",
+      TestEnumerable.new, :enum_for
+    )
+  end
+
   def test_find_index
     assert_send_type "() -> ::Enumerator[String, Integer?]", TestEnumerable.new,
                      :find_index
@@ -211,7 +225,7 @@ class EnumerableTest2 < Test::Unit::TestCase
   end
 
   def test_inject
-    assert_send_type "(String init, Symbol method) -> untyped", TestEnumerable.new, :inject, '', :<<
+    assert_send_type "(String init, Symbol method) -> untyped", TestEnumerable.new, :inject, +'', :<<
     assert_send_type "(Symbol method) -> String", TestEnumerable.new, :inject, :+
     assert_send_type("(Integer initial) { (Integer, String) -> Integer } -> Integer", TestEnumerable.new, :inject, 0) do |memo, item|
       memo ^ item.hash
