@@ -88,3 +88,26 @@ class EnumeratorYielderTest < Test::Unit::TestCase
     end.next
   end
 end
+
+class EnumeratorChainInstanceTest < Test::Unit::TestCase
+  include TestHelper
+
+  testing "::Enumerator::Chain[::Integer]"
+
+  def test_each
+    enum = Enumerator::Chain.new 1..3, [4, 5]
+    assert_send_type "() { (Integer) -> nil } -> Enumerator::Chain[Integer]",
+                     enum, :each do end
+  end
+end
+
+class EnumeratorChainSingletonTest < Test::Unit::TestCase
+  include TestHelper
+
+  testing "singleton(::Enumerator::Chain)"
+
+  def test_class_new
+    assert_send_type "(Range[Integer], Array[Integer]) -> Enumerator::Chain[Integer]",
+                     Enumerator::Chain, :new, 1..3, [4, 5]
+  end
+end
